<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translation>Acerca de Tiled</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(vea en el fichero AUTHORS una lista completa de los colaboradores)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Usted puede modificar y redistribuir este programa bajo los terminos de la GPL (versión 2 ó superior). Una copia de la GPL se encuentra en el fichero &apos;COPYING&apos; que acompaña a Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>&amp;Save map before executing</source>
        <translation>&amp;Guardar mapa antes de ejecutarlo</translation>
    </message>
    <message>
        <source>Save map before executing</source>
        <translation type="obsolete">Guardar el mapa antes de ejecutarlo</translation>
    </message>
</context>
<context>
    <name>Droidcraft::DroidcraftPlugin</name>
    <message>
        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
        <source>This is not a valid Droidcraft map file!</source>
        <translation>¡Este no es un tipo de fichero de mapa Droidcraft válido!</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>The map needs to have exactly one tile layer!</source>
        <translation>¡El mapa necesita tener exactamente una sola capa de patrones!</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>The layer must have a size of 48 x 48 tiles!</source>
        <translation>¡La capa debe tener un tamaño de 48x48 patrones!</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Could not open file for writing.</source>
        <translation>No se pudo abrir el archivo para escritura.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Droidcraft map files (*.dat)</source>
        <translation>Ficheros de mapa Droidcraft (*.dat)</translation>
    </message>
</context>
<context>
    <name>Lua::LuaPlugin</name>
    <message>
        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
        <source>Could not open file for writing.</source>
        <translation>No se pudo abrir el archivo para escritura.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Lua files (*.lua)</source>
        <translation>Ficheros Lua (*.lua)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation>Tiled</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Recent Files</source>
        <translation>Archivos &amp;recientes</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>&amp;Mapa</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation type="obsolete">&amp;Capas</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation>Barra de Herramientas Principal</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>&amp;Acerca de Tiled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>&amp;Redimensionar Mapa...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>&amp;Propiedades del Mapa...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation>AutoMapa</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;Grid</source>
        <translation>Mostrar &amp;Rejilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation>CTRL+G</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>Guardar &amp;como...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;New...</source>
        <translation>&amp;Nuevo...</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Save As &amp;Image...</source>
        <translation>Guardar &amp;Imagen como...</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>&amp;Export As...</source>
        <translation>&amp;Exportar como...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation>&amp;Añadir un conjunto de Patrones Externo...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation>&amp;Ajustar a la Rejilla</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation>C&amp;errar todo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation>Ctrl+Shift+W</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">&amp;Subir Capa</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation type="obsolete">Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">&amp;Bajar Capa</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation type="obsolete">Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="obsolete">Seleccionar &amp;Todo</translation>
    </message>
    <message>
        <source>Select &amp;None</source>
        <translation type="obsolete">Seleccionar &amp;Nada</translation>
    </message>
    <message>
        <source>New...</source>
        <translation type="obsolete">Nuevo...</translation>
    </message>
    <message>
        <location line="-113"/>
        <source>New &amp;Tileset...</source>
        <translation>Nuevo conjunto de &amp;Patrones...</translation>
    </message>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="obsolete">&amp;Eliminar Capa</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">Añadir Capa de &amp;Patrones...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">Añadir Capa de &amp;Objetos...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Layer</source>
        <translation type="obsolete">&amp;Duplicar Capa</translation>
    </message>
    <message>
        <source>Ctrl+Shift+D</source>
        <translation type="obsolete">Ctrl+Shift+D</translation>
    </message>
    <message>
        <source>Layer &amp;Properties...</source>
        <translation type="obsolete">&amp;Propiedades de la Capa...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>Reducir</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>Tamaño Normal</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>Save As Image...</source>
        <translation type="obsolete">Guardar como Imagen...</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>&amp;Desplazar Mapa...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>Desplazar todo en la capa</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>Pre&amp;ferencias...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>Limpiar archivos recientes</translation>
    </message>
</context>
<context>
    <name>MapObjectItem</name>
    <message>
        <source>&amp;Duplicate</source>
        <translation type="obsolete">&amp;Duplicar</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Eliminar</translation>
    </message>
    <message>
        <source>&amp;Properties...</source>
        <translation type="obsolete">&amp;Propiedades...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Object</source>
        <translation type="obsolete">&amp;Duplicar Objeto</translation>
    </message>
    <message>
        <source>&amp;Remove Object</source>
        <translation type="obsolete">&amp;Eliminar Objeto</translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">&amp;Propiedades del Objeto...</translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
        <source>Not a map file.</source>
        <translation>No es un archivo de Mapas.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation>No es un archivo con un conjunto de patrones.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation>%3

Línea %1, columna %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation>Archivo no encontrado: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation>Incapaz de leer archivo: %1</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation>Orientación del Mapa no soportada: &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation>Parámetros del conjunto de patrones no válidos para el conjunto de patrones &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation>Error mientras se cargaba el conjunto de patrones &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation>ID de Patrón no válido: %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation>Error cargando la imagen del conjunto de patrones:
&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation>Demasiados elementos &lt;Patrón&gt;</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+72"/>
        <location line="+39"/>
        <location line="+90"/>
        <source>Invalid tile: %1</source>
        <translation>Patrón no válido: %1</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Unknown encoding: %1</source>
        <translation>Codificación desconocida: %1</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation>Método de compresión &apos;%1&apos; no soportado</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation>Datos corruptos para la Capa &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation>Incapaz de interpretar patrón en (%1,%2) en la capa &apos;%3&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">ID global del Patrón no válido (inferior a 0): %1</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile used but no tilesets specified</source>
        <translation>Patrón usado, pero no especificado en el conjunto de patrones</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
        <source>Could not open file for writing.</source>
        <translation>No se pudo abrir el archivo para escritura.</translation>
    </message>
</context>
<context>
    <name>NewImageLayerDialog</name>
    <message>
        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
        <source>New Tileset</source>
        <translation>Nuevo conjunto de Patrones</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image layer</source>
        <translation>Capa de Imagen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nombre:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Explorar...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>Usar color transparente:</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>Nuevo Mapa</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>Tamaño del Mapa</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>Alto:</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>Tamaño del Patrón</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>Orientación:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>Ortogonal</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>Isométrico</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>Nuevo conjunto de Patrones</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation>Conjunto de Patrones</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nombre:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Explorar...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>Usar color transparente:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation>Patrones</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>Margen:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>Alto:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>Espaciado:</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>Alto:</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>Desplazar Mapa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>Desplazar el contenido del Mapa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>Cubrir</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>Capas:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>Todas las capas visibles</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>Todas las capas</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>La capa seleccionada</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>Limites:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>El Mapa al completo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>La selección actual</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>Guardando y Cargando</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>&amp;Almacenar la capa de patrones como:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation>XML</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (sin comprimir)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (con compresión gzip)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (con compresión zlib)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation>CSV</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>&amp;Recargar las imagenes con el conjunto de patrones cuando cambien</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>No activar por defecto, desde que una referencia a un DTD externo es una causa conocida de problemas con algunos parser de XML.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>Incluir la referencia &amp;DTD en los mapas guardados</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>&amp;Idioma:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation>Pintado &amp;acelerado por Hardware (OpenGL)</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Bucket Fill Tool</source>
        <translation type="obsolete">Herramienta de Rellenado</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>Redimensionar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Alto:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation>Desplazamiento</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>Guardar como Imagen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>Localización</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Explorar...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>Solo incluir las &amp;capas visibles</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>Usar el nivel actual de &amp;aumento</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation>&amp;Dibujar guía para patrones</translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation>No se pudo abrir el archivo para escritura.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation>Archivos de mapa T-Engine4 (*.lua)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AbstractObjectTool</name>
    <message numerus="yes">
        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
        <location line="+54"/>
        <source>Duplicate %n Object(s)</source>
        <translation>
            <numerusform>Duplicar Objeto</numerusform>
            <numerusform>Duplicar %n Objetos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-53"/>
        <location line="+71"/>
        <source>Remove %n Object(s)</source>
        <translation>
            <numerusform>Eliminar Objeto</numerusform>
            <numerusform>Eliminar %n Objetos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-62"/>
        <location line="+72"/>
        <source>Move %n Object(s) to Layer</source>
        <translation>
            <numerusform>Mover Objeto a la Capa</numerusform>
            <numerusform>Mover %n Objetos a la Capa</numerusform>
        </translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Object &amp;Properties...</source>
        <translation>&amp;Propiedades del Objeto...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation>¡Se encontraron multiples capas %1!</translation>
    </message>
    <message>
        <location line="+110"/>
        <source>No ruleRegions layer found!</source>
        <translation>¡No se encontraron capas ruleRegions!</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation>¡No se encontró un set de capas!</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation>¡No se encontró la capa ruleSet!</translation>
    </message>
    <message>
        <location line="+212"/>
        <source>Tile</source>
        <translation>Patrón</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+497"/>
        <source>No set layer found!</source>
        <translation>¡No se encontró un set de capas!</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Apply AutoMap rules</source>
        <translation>Aplicar reglas de AutoMapa</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation>No se encontró el archivo de reglas en:
%1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation>Error abriendo el archivo de reglas:
%1</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation>Archivo no encontrado:
%1</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation>Fallo la carga de las reglas del mapa:
%1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>Herramienta de Rellenado</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation>R</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
        <source>Execute Command</source>
        <translation>Ejecutar orden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Error Executing Command</source>
        <translation>Error ejecutando orden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>You do not have any commands setup.</source>
        <translation>Usted no tiene ninguna orden preparada.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation>Editar ordenes...</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Edit Commands...</source>
        <translation>Editar Ordenes...</translation>
    </message>
    <message>
        <source>There was an error running the command</source>
        <translation type="obsolete">Hubo un error ejecutando la orden</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
        <source>Open in text editor</source>
        <translation>Abrir en el editor de texto</translation>
    </message>
    <message>
        <location line="+92"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation>&lt;Nueva Orden&gt;</translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation>Establecer un nombre para esta orden</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation>Establecer la orden de consola a ejecutar</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation>Mostrar u ocultar esta orden en la lista de ordenes</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation>Añadir una nueva orden</translation>
    </message>
    <message>
        <location line="+101"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation>Orden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Move Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move Down</source>
        <translation>Bajar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Execute</source>
        <translation>Ejecutar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Execute in Terminal</source>
        <translation>Ejecutar en la Consola</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location line="+84"/>
        <source>%1 (copy)</source>
        <translation>%1 (copiar)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>New command</source>
        <translation>Nueva orden</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
        <source>Edit Commands</source>
        <translation>Editar Ordenes</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandProcess</name>
    <message>
        <location filename="../src/tiled/command.cpp" line="+122"/>
        <source>Unable to create/open %1</source>
        <translation>No es posible crear ó abrir %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Unable to add executable permissions to %1</source>
        <translation>No es posible dar permiso de ejecución a %1</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>The command failed to start.</source>
        <translation>La orden fue incapaz de iniciarse.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command crashed.</source>
        <translation>La orden se bloqueó.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command timed out.</source>
        <translation>La orden agotó el tiempo.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>An unknown error occurred.</source>
        <translation>Ocurrió un error desconocido.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Executing %1</source>
        <translation>Error ejecutando %1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+100"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation>Insertar Objetos</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation>Insertar Objetos Patrones</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation>P</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>Goma</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation>G</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
        <source>Image Layer</source>
        <translation>Capa de Imagen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Browse...</source>
        <translation>Explorar...</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Transparent color:</source>
        <translation>Color Transparente:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Layer Image</source>
        <translation>Capa de Imagen</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
        <source>Layers</source>
        <translation>Capas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>Transparencia:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Propiedades...</translation>
    </message>
    <message>
        <source>Layer</source>
        <translation type="obsolete">Capa</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
        <location line="+8"/>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <location line="-7"/>
        <location line="+6"/>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Error while opening map</source>
        <translation type="obsolete">Error en la apertura del mapa</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>Open Map</source>
        <translation>Abrir Mapa</translation>
    </message>
    <message>
        <location line="-13"/>
        <location line="+76"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Archivos de mapas de Tiled (*.tmx)</translation>
    </message>
    <message>
        <source>Error while saving map</source>
        <translation type="obsolete">Error en la grabación del mapa</translation>
    </message>
    <message>
        <location line="-451"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+1047"/>
        <source>&amp;Layer</source>
        <translation>&amp;Capa</translation>
    </message>
    <message>
        <location line="-910"/>
        <source>Ctrl+PgUp</source>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ctrl+PgDown</source>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Error Opening Map</source>
        <translation>Error Abriendo Mapa</translation>
    </message>
    <message>
        <location line="+73"/>
        <location line="+135"/>
        <source>All Files (*)</source>
        <translation>Todos los ficheros (*)</translation>
    </message>
    <message>
        <location line="-94"/>
        <location line="+141"/>
        <source>Error Saving Map</source>
        <translation>Error Guardando Mapa</translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation>untitled.tmx</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>Cambios sin guardar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>Hay cambios sin guardar. ¿Desea guardarlos ahora?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation>Exportar como...</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation>Formato de archivo desconocido</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation>El nombre de fichero dado tiene una extensión desconocida.</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Paste Objects</source>
        <translation>Pegar Objetos</translation>
    </message>
    <message>
        <location line="+370"/>
        <source>[*]%1 - Tiled</source>
        <translation>[*]%1 - Tiled</translation>
    </message>
    <message>
        <source>Add Tilesets</source>
        <translation type="obsolete">Añadir conjunto de Patrones</translation>
    </message>
    <message>
        <location line="-291"/>
        <source>Add External Tileset</source>
        <translation>Añadir conjunto de Patrones Externo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Ficheros de conjunto de patrones de Tiled (*.tsx)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation>Error Leyendo conjunto de Patrones</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation>Mapeado Automático</translation>
    </message>
    <message>
        <location line="+120"/>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>Add Tile Layer</source>
        <translation type="obsolete">Añadir capa de Patrones</translation>
    </message>
    <message>
        <source>Add Object Layer</source>
        <translation type="obsolete">Añadir capa de Objetos</translation>
    </message>
    <message>
        <source>Layer name:</source>
        <translation type="obsolete">Nombre de la Capa:</translation>
    </message>
    <message>
        <source>New Layer</source>
        <translation type="obsolete">Nueva Capa</translation>
    </message>
    <message>
        <source>Layer</source>
        <translation type="obsolete">Capa</translation>
    </message>
    <message>
        <source>%1[*] - Tiled</source>
        <translation type="obsolete">%1[*] - Tiled</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
        <source>untitled.tmx</source>
        <translation>untitled.tmx</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Resize Map</source>
        <translation>Redimensionar Mapa</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset Map</source>
        <translation>Desplazar Mapa</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation>Capa de patrones %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation>Capa de Objetos %1</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Copy of %1</source>
        <translation>Copiar desde %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>Duplicar Capa</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Merge Layer Down</source>
        <translation>Mezclar capa hacía abajo</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Tile</source>
        <translation>Patrón</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation>Cambios en el conjunto de Patrones</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+126"/>
        <source>Select &amp;All</source>
        <translation>Seleccionar &amp;Todo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation>Seleccionar &amp;Nada</translation>
    </message>
    <message>
        <location line="-81"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">Añadir Capa de &amp;Patrones...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">Añadir Capa de &amp;Objetos...</translation>
    </message>
    <message>
        <location line="+87"/>
        <source>&amp;Duplicate Layer</source>
        <translation>&amp;Duplicar Capa</translation>
    </message>
    <message>
        <location line="-79"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>&amp;Crop to Selection</source>
        <translation>&amp;Recortar la Selección</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Add &amp;Tile Layer</source>
        <translation>Añadir Capa de &amp;Patrones</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer</source>
        <translation>Añadir Capa de &amp;Objetos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Merge Layer Down</source>
        <translation>&amp;Mezclar Capas hacía Abajo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Layer</source>
        <translation>&amp;Eliminar Capa</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">&amp;Subir Capa</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">&amp;Bajar Capa</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Select Pre&amp;vious Layer</source>
        <translation>Seleccionar la Capa Pre&amp;via</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;Next Layer</source>
        <translation>Seleccionar la &amp;Próxima Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>R&amp;aise Layer</source>
        <translation>S&amp;ubir Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Lower Layer</source>
        <translation>&amp;Bajar Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show/&amp;Hide all Other Layers</source>
        <translation>Mostrar/&amp;Ocultar el Resto de Capas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer &amp;Properties...</source>
        <translation>&amp;Propiedades de la Capa...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <source>Layer 1</source>
        <translation type="obsolete">Capa 1</translation>
    </message>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation>Capa de Patrones 1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation>Falló al cargar la imagen de conjunto de patrones &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation>¡No se encontraron patrones en la imagen del conjunto de patrones usando las dimensiones, margen y espaciado de patrones suministradas!</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>Imagen con el conjunto de Patrones</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>Capa de Objetos</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>Objeto</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nombre:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Tipo:</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Change Object</source>
        <translation>Modificar Objeto</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
        <location line="+110"/>
        <source>Select Objects</source>
        <translation>Seleccionar Objetos</translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+109"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message numerus="yes">
        <source>Duplicate %n Object(s)</source>
        <translation type="obsolete">
            <numerusform>Duplicar Objeto</numerusform>
            <numerusform>Duplicar %n Objetos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Remove %n Object(s)</source>
        <translation type="obsolete">
            <numerusform>Eliminar Objeto</numerusform>
            <numerusform>Eliminar %n Objetos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Move %n Object(s) to Layer</source>
        <translation type="obsolete">
            <numerusform>Mover Objeto a la Capa</numerusform>
            <numerusform>Mover %n Objetos a la Capa</numerusform>
        </translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">&amp;Propiedades del Objeto...</translation>
    </message>
    <message numerus="yes">
        <location line="+117"/>
        <source>Move %n Object(s)</source>
        <translation>
            <numerusform>Mover Objeto</numerusform>
            <numerusform>Mover %n Objetos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>Configuración por defecto</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
        <source>%1 Properties</source>
        <translation>%1 Propiedades</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;nueva propiedad&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>Guardar como Imagen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 ya existe.
¿Quiere reemplazarla?</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>Selección Rectangular</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - Rectángulo: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+281"/>
        <source>Stamp Brush</source>
        <translation>Brocha de Estampar</translation>
    </message>
    <message>
        <location line="-278"/>
        <location line="+279"/>
        <source>B</source>
        <translation>B</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
        <source>Remove Tileset</source>
        <translation>Elimina conjunto de Patrones</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation>¡El conjunto de patrones &quot;%1&quot; está siendo todavía utilizado por el mapa!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation>¿Eliminar este conjunto de patrones y todas las referencias a patrones de dicho conjunto?</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Tilesets</source>
        <translation>Conjunto de Patrones</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Propiedades...</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
        <source>Tile &amp;Properties...</source>
        <translation>&amp;Propiedades del Patrón...</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation>&amp;Exportar conjuntos de Patrones como...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation>&amp;Importar conjuntos de Patrones</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show &amp;Grid</source>
        <translation>Mostrar &amp;Rejilla</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Tile</source>
        <translation>Patrón</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation>Exportar conjuntos de Patrones</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Ficheros de conjuntos de patrones de Tiled (*.tsx)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <source>Undo Stack</source>
        <translation type="obsolete">Histórico</translation>
    </message>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation>&lt;Vacía&gt;</translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation>¡Encontradas múltiples capas de colisiones!</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation>¡No se encontró capa de colisiones!</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation>No se pudo abrir el archivo para escritura.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation>Ficheros de colisiones TMW-eAthena (*.wlk)</translation>
    </message>
    <message>
        <source>TMW-eAthena collision files 2 (*.wlk2)</source>
        <translation type="obsolete">Ficheros de colisiones TMW-eAthena 2 (*.wlk2)</translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <source>XML map reader (*.tmx)</source>
        <translation type="obsolete">Lector de mapas XML (*.tmx)</translation>
    </message>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">No se pudo abrir el archivo para escritura.</translation>
    </message>
    <message>
        <source>XML map writer (*.tmx)</source>
        <translation type="obsolete">Escritor de mapas XML (*.tmx)</translation>
    </message>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Archivos de mapas de Tiled (*.tmx)</translation>
    </message>
</context>
<context>
    <name>TmxReader</name>
    <message>
        <source>Not a map file.</source>
        <translation type="obsolete">No es un archivo de Mapas.</translation>
    </message>
    <message>
        <source>Not a tileset file.</source>
        <translation type="obsolete">No es un archivo con un conjunto de patrones.</translation>
    </message>
    <message>
        <source>%3

Line %1, column %2</source>
        <translation type="obsolete">%3

Línea %1, columna %2</translation>
    </message>
    <message>
        <source>File not found: %1</source>
        <translation type="obsolete">Archivo no encontrado: %1</translation>
    </message>
    <message>
        <source>Unable to read file: %1</source>
        <translation type="obsolete">Incapaz de leer archivo: %1</translation>
    </message>
    <message>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="obsolete">Orientación del Mapa no soportada: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="obsolete">Parámetros del conjunto de patrones no válidos para el conjunto de patrones &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="obsolete">Error mientras se cargaba el conjunto de patrones &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Invalid tile ID: %1</source>
        <translation type="obsolete">ID de Patrón no válido: %1</translation>
    </message>
    <message>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="obsolete">Error cargando la imagen del conjunto de patrones:
&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="obsolete">Demasiados elementos &lt;tile&gt;</translation>
    </message>
    <message>
        <source>Invalid tile: %1</source>
        <translation type="obsolete">Patrón no válido: %1</translation>
    </message>
    <message>
        <source>Unknown encoding: %1</source>
        <translation type="obsolete">Codificación desconocida: %1</translation>
    </message>
    <message>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="obsolete">Método de compresión &apos;%1&apos; no soportado</translation>
    </message>
    <message>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="obsolete">Datos corruptos para la Capa &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="obsolete">Incapaz de interpretar patrón en (%1,%2) en la capa &apos;%3&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">ID global del Patrón no válido (inferior a 0): %1</translation>
    </message>
    <message>
        <source>Tile used but no tilesets specified</source>
        <translation type="obsolete">Patrón usado, pero no especificado en el conjunto de patrones</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
        <source>TMX Viewer</source>
        <translation>TMX Viewer</translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>Añadir Capa</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>Eliminar Capa</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
        <source>Add Object</source>
        <translation>Añadir Objeto</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Remove Object</source>
        <translation>Eliminar Objeto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>Modificar Objeto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>Cambiar las propiedades de la Capa de Objetos</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>Cambiar %1 Propiedades</translation>
    </message>
    <message>
        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>Cambiar Selección</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>Rellenar Área</translation>
    </message>
    <message>
        <source>Move Layer Down</source>
        <translation type="obsolete">Bajar Capa</translation>
    </message>
    <message>
        <source>Move Layer Up</source>
        <translation type="obsolete">Subir Capa</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>Mover Objeto</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>Desplazar Capa</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>Pintar</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>Renombrar Capa</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>Redimensionar Capa</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>Redimensionar Mapa</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>Redimensionar Objeto</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation>Añadir conjunto de Patrones</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation>Eliminar conjunto de Patrones</translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation>Mover conjunto de Patrones</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
        <source>Import Tileset</source>
        <translation>Importar conjunto de Patrones</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation>Exportar conjunto de Patrones</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation>Mover Objeto a la Capa</translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Lower Layer</source>
        <translation>Bajar Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Raise Layer</source>
        <translation>Subir Capa</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
        <source>Change Image Layer Properties</source>
        <translation>Cambiar las propiedades de la Capa de Imagen</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>Ficheros de imagen</translation>
    </message>
</context>
</TS>
